package
Version:
v0.0.0-...-287ff3b
Opens a new window with list of versions in this module.
Published: Apr 19, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetLocalPeerID() [20]byte
Unmarshal parse the byte list to peer list
6 byte for one peer
4 byte for IP
2 byte for Port
type TrackerResponse struct {
Interval int `bencode:"interval"`
Peers string `bencode:"peers"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.